@@ -12,18 +12,18 @@ class Company:
 		self.conn, self.c = open_connection(DB_FILE)
 		NICKNAME_FILE = pkg_resources.resource_filename('ticker_to_searchable_terms', 'DB/Nicknames.db')
 		self.n_conn, self.n_c = open_connection(NICKNAME_FILE)
-		self.terms = self.pop(ticker)
+		self.terms = self.pop()
 		self.n_conn.close()
 		self.conn.close()
 
 		
 
-	def pop(self, ticker):
-		self.ticker = ticker.upper()
+	def pop(self):
+		ticker = self.ticker
 		results = find_ticker(ticker, self.c)
 		ticker = results[0]
 		company_name = results[1].strip()
-		alt_company_name = results[-1]
+		alt_company_name = results[-1].strip()
 		people = []
 		for x in results[2:-1]:
 			if x != 'NULL':
